@@ -76,7 +76,10 @@ class Config:
     self.key = key
 
 def run(config):
-
+  """
+  Will accept to upload a file only once. When a file has been uploaded,
+  it will refuse any other upload.
+  """
   app = Flask(__name__)
 
   if config.log_file_path is not None:
@@ -101,6 +104,10 @@ def run(config):
           if key == config.key:
             file.save(config.upload_file)
             return redirect('/')
+          else:
+            # Bad key
+            template = app.open_resource('templates/badkey.html')
+            return template.read()
       template = app.open_resource('templates/index.html')
       return template.read()
 
